# Padding & Truncation

::: torchlinops.linops.Pad
    options:
        inherited_members: false
        members:
            - __init__

::: torchlinops.linops.Crop

::: torchlinops.linops.Truncate
    options:
        inherited_members: false
        members:
            - __init__

::: torchlinops.linops.PadDim
    options:
        inherited_members: false
        members:
            - __init__
